#!/bin/bash

#This script generates all necessary files for building djplay.
#After running this script it is possible to run ./configure to configure 
#the djplay package in the familiar manner:

#./configure
#make
#make install

#Files generated by this script:
# All Makefile.in files.
# configure script.

#***** functions *****

#Cleans directory of temporary files.
function cleanup()
{
echo -n "Cleaning directory.. " 

#Remove temporary autoconf files..
if test -e autom4te.cache; then
    rm -r autom4te.cache;
fi
#Remove temporary aclocal files..
if test -e aclocal.m4; then
    rm -r aclocal.m4
fi

echo "done."
}

#Displays further directions after successful generation. 
function showDirections()
{
    echo -e "*********************************************************"
    echo -e "You can now proceed to build and install the software:\n"
    echo -e "\t./configure" 
    echo -e "\tmake"
    echo -e "\tmake install" 
    echo -e "\nAlternatively, run 'make dist' to create a distributable" 
    echo -e "source package."
    echo    "*********************************************************"
}          

#******* main *******

#Check for configure.ac
if ! test -e configure.ac; then
    echo "Error: missing configure.ac"
    exit 1
fi

#Run libtoolize to generate necessary libtool stuff..
echo -n "Generating libtool prerequisites.. "
if libtoolize --force; then
    echo "done."
else echo "failed!"; cleanup; exit 1;
fi

#Run autoconf to generate configure script..
echo -n "Generating configure script.. "
if aclocal -I m4 && autoconf; then
    echo "done."
else echo "failed!"; cleanup; exit 1;
fi

#Run automake to generate Makefile.in files.
echo -n "Generating Makefile.in files.. "
if automake --add-missing --copy; then 
    echo "done.";
else echo "failed!"; cleanup; exit 1;
fi

#Run autoheader to generate header file
echo -n "Generating Makefile.in files.. "
if autoheader; then 
    echo "done.";
else echo "failed!"; cleanup; exit 1;
fi

#Clean directory and show directions on success:
cleanup
showDirections
exit 0
