#include <qpainter.h>
#include <qpen.h>
#include <qpixmap.h>
#include "display.h"
#include "mainwnd.h"
#include <stdio.h>
#include <qtimer.h>
#include <math.h>
#include "jack.h"

DDisplay::DDisplay(QWidget *parent, const char *name, WFlags f) : QWidget(parent, name, f)
{
	ind_timer=new QTimer(this);
	blink_on=0;
}

DDisplay::~DDisplay()
{
}

void DDisplay::paintEvent(QPaintEvent *pe)
{
	QPixmap pm(size());
	QPainter p;
	p.begin(&pm, this);

	draw(&p);

	bitBlt(this, 0, 0, &pm);
}

void DDisplay::draw(QPainter *p)
{
//	QPen erp(QColor(192, 192, 192));
//	QBrush erb(QColor(192, 192, 192));

	QPen bgp(QColor(0, 0, 0));
	QBrush bgb(QColor(0, 0, 0));

//	p->setPen(erp);
//	p->setBrush(erb);

//	p->drawRect(rect());

	p->setPen(bgp);
	p->setBrush(bgb);

	p->drawRect(rect());

	int max_samp=((MainWnd *)parent())->get_max_peak_value();
	int samp=((MainWnd *)parent())->get_peak_value();

	if(samp > max_samp*3/4 || ind_timer->isActive())
	{
		QRect ind(width()-15, 10, 5, 5);
		QPen indp(QColor(36, 152, 255));
		QBrush indb(QColor(36, 152, 255));

		p->setPen(indp);
		p->setBrush(indb);

		p->drawRect(ind);
		if(!ind_timer->isActive())
		{
			ind_timer->start(150, true);
		}
	}

	QPen tp(QColor(36, 152, 255));
	p->setPen(tp);
	QString strText;
	QFont f=font();
	f.setPixelSize(16);
	p->setFont(f);
	strText.sprintf("%2.1lf%%", ((MainWnd*)parent())->get_base_pitch());
	QRect rct=p->boundingRect(50, 50, 10000, 10000, AlignLeft | AlignTop, strText);
	p->drawText(width()-rct.width()-15, rct.height()+5, strText);

	unsigned frame=((MainWnd *)parent())->get_total_frames()-((MainWnd *)parent())->get_frame();
	unsigned basetime=frame/(((MainWnd *)parent())->get_sample_rate()/100);
	unsigned hours=basetime/360000;
	unsigned minutes=(basetime/6000)%60;
	unsigned seconds=(basetime/100)%60;
	unsigned twips=basetime%100;
	bool blink_time=0;
	if(twips < 50)
		blink_on=1;
	else
		blink_on=0;
	if(hours < 1 && minutes < 2 && (minutes < 1 || seconds < 30) && ((MainWnd *)parent())->isPlaying())
		blink_time=1;
	strText.sprintf("%u:%02u:%02u", hours, minutes, seconds);
	f=font();
	f.setPixelSize(32);
	p->setFont(f);
	rct=p->boundingRect(50, 32, 10000, 10000, AlignLeft | AlignTop, strText);
	if(!blink_time || blink_on)
		p->drawText(50, 32, strText);
	strText.sprintf("%02d", twips);
	f.setPixelSize(18);
	p->setFont(f);
	if(!blink_time || blink_on)
		p->drawText(rct.right()+5, 32, strText);

	f.setPixelSize(12);
	p->setFont(f);
	QPen np(QColor(255, 255, 255));
	p->setPen(np);
#if 0
	QString raw_name=((MainWnd *)parent())->fileName();
	int pos;;
	if((pos=raw_name.find(" - ")) == -1)
	{
		p->drawText(5, 57, raw_name);
	}
	else
	{
		QString artist=raw_name.left(pos);
		QString title=raw_name.mid(pos+3);

		p->drawText(5, 50, artist);
		p->drawText(5, 63, title);
	}
#endif

	if(((MainWnd *)parent())->get_source())
	{
		QString artist=((MainWnd *)parent())->get_source()->artist();
		QString title=((MainWnd *)parent())->get_source()->title();

		if(artist != "" && title != "")
		{
			p->drawText(5, 50, artist);
			p->drawText(5, 63, title);
		}
		else
		{
			if(artist == "")
				artist=title;
			p->drawText(5, 57, artist);
		}
	}
	QPen bpm_pen(QColor(244, 109, 19));
	p->setPen(bpm_pen);

	f=font();
	f.setPixelSize(16);
	p->setFont(f);

	QString strBPM;
	float bpm=((MainWnd *)parent())->bpm();
	if(bpm == -1.0f)
		strBPM="---.-";
	else if(bpm == 0.0f)
		strBPM="";
	else
	{
		double base_pitch=((MainWnd*)parent())->get_base_pitch();
		strBPM.sprintf("%3.1f", bpm*(1.0f+((float)base_pitch/100.0f)));
	}

	rct=p->boundingRect(50, 50, 10000, 10000, AlignLeft | AlignTop, strBPM);
	p->drawText(width()-rct.width()-70, rct.height()+5, strBPM);

	((MainWnd *)parent())->Draw3dRect(p, rect(), true, QColor(255, 255, 255), QColor(128, 128, 128));

	QPixmap wave(rect().width()-2, 32);
	((MainWnd *)parent())->get_wave_pixmap(&wave);
	p->drawPixmap(1, height()-34, wave);
}
