#ifndef _FRAME_H_INCLUDED
#define _FRAME_H_INCLUDED

#include <qwidget.h>
#include <qthread.h>
#include "mainwnd.h"
#include "jacklow.h"
#include "config.h"
#include "vthread.h"
#ifdef HAVE_LIBSDL
extern "C" {
#include <SDL.h>
}
#endif

class QSocketNotifier;
class QTimer;
class Mixer;
class Playlist;
class VThread;
class StreamSource;
class Metatracker;

class Frame : public QWidget
{
Q_OBJECT
public:
	Frame(QWidget *parent, const char *name, WFlags f);
	~Frame();

	void setFrames(MainWnd *f1, MainWnd *f2);
	MainWnd *left();
	MainWnd *right();
	MainWnd *player(int p);
	Metatracker *metatracker;
	Mixer *mixer();
	Client *client();
	Port *pfl_left;
	Port *pfl_right;
	void setMixer(Mixer *mixer);
	Playlist *playlist();
	void setPlaylist(Playlist *p);
	unsigned char **get_frame_buffer(int player);
	void enableLeftVideo(bool on);
	void enableRightVideo(bool on);
	void new_track(int player_number);
	void setVideoMode();

	unsigned char **left_buffer;
	unsigned char **right_buffer;
	unsigned char **blank_buffer;

	QMutex clear_lock;
protected:
#ifdef HAVE_LIBSDL
	SDL_Surface *display;
	VThread *vthread;
	void *wm_info;
	unsigned long sdl_frame;
#endif
	Playlist *s_playlist;
	Mixer *s_mixer;
	Client *j_client;
	int joy_fd;
	QSocketNotifier *sn_read;
	MainWnd *frame1, *frame2;
	int button_states[4];
	int button_delta[4];
	int direction[2];
	int last_button[2];
	int started[2];
	int lowcount[2];
	int ignore[2];
	unsigned long last_event;
	unsigned prev_keys;
	QTimer *wheel_timer;
	QTimer *key_timer;
	QWidget *video;
	float left_factor;
	float right_factor;
	bool lv_on;
	bool rv_on;
	bool video_mode_on;
	StreamSource *left_source;
	StreamSource *right_source;
public slots:
	void VideoXFader_valueChanged(int v);
protected slots:
	void wheel_timeout();
	void key_timeout();
	void joyData(int socket);
	void closeEvent(QCloseEvent *e);
signals:
	void windowClosed();
friend class VThread;
};
#endif
